// This version trig the shield to start measure frequency on LOW input.
// During the measurement, the Arduino will do something else, in this example make the LED blink on Pin 13.
// This example demonstrate how the counter shield can work on its own and Arduino is doing something else at the same time.
//
#include <SPI.h>


// ==============================================================================================================
//                                              Define Pins
// ==============================================================================================================

// Pins below are used by the Counter PCB and can not be changed
#define Ready 3                                                       // Define Ready Pin
#define Trigger 2                                                     // Define Trig Pin
#define RFInput 4                                                     // Define RF input Pin

#define LED 13                                                        // Define LED on Arduino board

// ==============================================================================================================
//                                           Define Variables
// ==============================================================================================================

long Incomming_Data=0;                                                // Counter Value

// ==============================================================================================================
//                                              Functions
// ==============================================================================================================
// The function  "StartCounter" initiate the shield to start counting frequency from selected input.
// The function trig the shield and will not wait for the shield-counter to be ready.

    long StartCounter(byte SignalInput){
    
	  unsigned long startedWaiting=0;                                   // Used for timeout
	  long CounterValue=0;                                              // Value from Counter

    // Check which input to connect to the counter (50 MHz input or 2.5 GHz)		
	  if(SignalInput==0) {
        digitalWrite(RFInput,LOW);                                    // Set Pin Low to select 50MHz input
	  }
        else{
        digitalWrite(RFInput,HIGH);                                   // Set Pin Low to select 2.5GHz input
	  }
    delay(50);   
    // Send a trig pulse High-Low to start counting
    digitalWrite(Trigger,HIGH);                                       // Trigger goes High
    delayMicroseconds(100);
    digitalWrite(Trigger,LOW);                                        // Trigger goes Low
    
    delayMicroseconds(100);
}
// ---------------------------------------------------------------------------------------------------------- END

// ==============================================================================================================
//                                              Functions
// ==============================================================================================================
// The function  "GetCounter" collect the counter value from the shield.
// 

    long GetCounterValue(){
    
    long CounterValue=0;                                              // Value from Counter
    
	  // Read all the bits to form the Counter value
    for (int Bitcounter = 1; Bitcounter <= 32; Bitcounter++) {
        digitalWrite(Trigger,HIGH);                                   // Trigger (Clock) goes High	
        delayMicroseconds(100);
		    CounterValue=CounterValue<<1;                                 // Shift Counter value one bit left
        if(digitalRead(Ready)==1){
            bitSet(CounterValue,0);                                   // If pin is high, set bit High 
        }
        digitalWrite(Trigger,LOW);                                    // Trigger (Clock) goes Low	
        delayMicroseconds(100);
    }  
    return CounterValue;                                              // Send back the counter Value
}	
// ---------------------------------------------------------------------------------------------------------- END




// ==============================================================================================================
//                                              SETUP
// ==============================================================================================================

void setup(){
    Serial.begin(9600);                                               // Init serial

    pinMode(Trigger, OUTPUT);                                         // Set Pin as Output
    digitalWrite(Trigger,LOW);                                        // Set Pin Low     
    pinMode(RFInput, OUTPUT);                                         // Set Pin as Output 
    digitalWrite(RFInput,LOW);                                        // Set Pin Low
    pinMode(Ready, INPUT);                                            // Set pin as Input

    pinMode(LED, OUTPUT);                                             // Set Pin as Output
    digitalWrite(LED,LOW);                                            // Set Pin Low    
 
    delay(10);          
}
// ==============================================================================================================
//                                              Loop
// ==============================================================================================================
void loop() {

    // Check if shield is ready for new measurement
    if(digitalRead(Ready)==0){
        // Shield is ready to start a measurement
        StartCounter(0);                                              // Trig the shield to start counting
    }
    // Here the Arduino Blinks the LED on pin 13
    digitalWrite(LED,HIGH);                                           // Set LED ON
    delay(100); 
    digitalWrite(LED,LOW);                                            // Set LED OFF
    delay(100);        

    // Check if shield is ready
    if(digitalRead(Ready)==1){
    //Shield has counted and result is ready to be fethed
    Incomming_Data=GetCounterValue();                                 // Get Counter Value Low input
    Serial.println(Incomming_Data);          
    delay(10);
    }
}    
